@@ -54,7 +54,7 @@ class ElectraForSequenceClassification(Module):
     def __init__(
             self, vocab_size: int, token_types: int, dim: int, pad_token_id: int,
             max_position_embeddings: int, ffn_size: int, n_heads: int, n_layers: int,
-            num_labels: int
+            num_labels: int, activation: str
     ):
         super().__init__()
 
@@ -63,16 +63,18 @@ class ElectraForSequenceClassification(Module):
             vocab_size=vocab_size, token_types=token_types, dim=dim, pad_token_id=pad_token_id,
             max_position_embeddings=max_position_embeddings, ffn_size=ffn_size, n_heads=n_heads, n_layers=n_layers)
         self.classifier = ElectraClassificationHead(dim, num_labels)
+        self.head_activation = torch.sigmoid if activation == 'sigmoid' else torch.softmax
 
     def forward(self, input_ids: Tensor, attention_mask: Tensor, token_type_ids: Optional[Tensor] = None):
-        sequence_output = self.transformer(input_ids, attention_mask, token_type_ids)
-        return self.classifier(sequence_output)
+        tensor = self.transformer(input_ids, attention_mask, token_type_ids)
+        tensor = self.classifier(tensor)
+        return self.head_activation(tensor)
 
     @classmethod
-    def from_pretrained(cls, model_path: str, num_labels: int) -> 'ElectraForSequenceClassification':
+    def from_pretrained(cls, model_path: str, num_labels: int, activation: str) -> 'ElectraForSequenceClassification':
         model = cls(
             vocab_size=30522, token_types=2, dim=768, pad_token_id=0, max_position_embeddings=512,
-            ffn_size=3072, n_heads=12, n_layers=12, num_labels=num_labels
+            ffn_size=3072, n_heads=12, n_layers=12, num_labels=num_labels, activation=activation
         )
         model.load_state_dict(state_dict=torch.load(os.path.join(model_path, 'pytorch_model.bin'), map_location='cpu'))
         model.eval()
